@@ -102,6 +102,7 @@ cMenuSetupMP3::cMenuSetupMP3(void)
   Add(new cMenuEditStraItem(tr("Setup.MP3$Background scan"),       &data.BgrScan, 3, scan));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Editor display mode"),   &data.EditorMode, tr("Filenames"), tr("ID3 names")));
   Add(new cMenuEditBoolItem(tr("Setup.MP3$Mainmenu mode"),         &data.MenuMode, tr("Playlists"), tr("Browser")));
+  Add(new cMenuEditBoolItem(tr("Setup.MP3$Keep selection menu"),   &data.KeepSelect));
   Add(new cMenuEditBoolItem(tr("Hide mainmenu entry"),             &data.HideMainMenu));
   Add(new cMenuEditIntItem( tr("Setup.MP3$Normalizer level"),      &data.TargetLevel, 0, MAX_TARGET_LEVEL));
   Add(new cMenuEditIntItem( tr("Setup.MP3$Limiter level"),         &data.LimiterLevel, MIN_LIMITER_LEVEL, 100));
@@ -144,6 +145,7 @@ void cMenuSetupMP3::Store(void)
   SetupStore("ReplayDisplay",    MP3Setup.ReplayDisplay  );
 #endif
   SetupStore("HideMainMenu",     MP3Setup.HideMainMenu   );
+  SetupStore("KeepSelect",       MP3Setup.KeepSelect     );
 }
 
 // --- cAsyncStatus ------------------------------------------------------------
@@ -482,6 +484,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
     bool valid=mgr->Info(-1,mode);
     bool changed=(!lastMode || mode->Hash!=lastMode->Hash);
     char buf[256];
+    if(changed) { d(printf("mp3-ctrl: mode change detected\n")) }
 
     if(valid) { // send progress to status monitor
       if(changed || mode->Loop!=lastMode->Loop || mode->Shuffle!=lastMode->Shuffle) {
@@ -565,7 +568,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
 	      flip=0;
 	      // fall through
 	    case 0:
-	      snprintf(buf,sizeof(buf),mode->Artist[0]?"%s - %s":"%s%s",mode->Title,mode->Artist);
+	      snprintf(buf,sizeof(buf),mode->Artist[0]?"%s - %s":"%s",mode->Title,mode->Artist);
 	      flipint=6;
 	      break;
 	    case 1:
@@ -598,6 +601,7 @@ void cMP3Control::ShowProgress(bool open, bool bigWin)
                 DisplayInfo(buf);
                 flush=true;
                 }
+              else { d(printf("mp3-ctrl: display info skip due to status active\n")) }
 #if VDRVERSNUM >= 10307
               }
 #endif
@@ -730,34 +734,32 @@ eOSState cMP3Control::ProcessKey(eKeys Key)
 
   switch(Key) {
     case kUp:
+    case kUp|k_Repeat:
       mgr->Next(); player->Play();
       break;
     case kDown:
+    case kDown|k_Repeat:
       if(!player->PrevCheck()) mgr->Prev();
       player->Play();
       break;
     case kLeft:
+    case kLeft|k_Repeat:
       if(bigwin) {
         if(top>0) { top-=rows; if(top<1) top=1; }
         break;
         }
       // fall through
-    case kLeft|k_Repeat:
-      if(bigwin) break;
-      // fall through
     case kFastRew:
     case kFastRew|k_Repeat:
       if(!player->IsStream()) player->SkipSeconds(-JUMPSIZE);
       break;
     case kRight:
+    case kRight|k_Repeat:
       if(bigwin) {
         if(top>0) top+=rows;
         break;
         }
       // fall through
-    case kRight|k_Repeat:
-      if(bigwin) break;
-      // fall through
     case kFastFwd:
     case kFastFwd|k_Repeat:
       if(!player->IsStream()) player->SkipSeconds(JUMPSIZE);
@@ -779,6 +781,9 @@ eOSState cMP3Control::ProcessKey(eKeys Key)
         greentime=time(0)+MULTI_TIMEOUT;
         }
       break;
+    case kPlay:
+      player->Play();
+      break;
     case kPause:
     case kYellow:
       if(!player->IsStream()) player->Pause();
@@ -1389,6 +1394,7 @@ eOSState cMenuMP3::Play(void)
   if(newpl->Load() && newpl->Count()) {
     isyslog("mp3: playback started with playlist %s", newpl->Name());
     cMP3Control::SetPlayList(newpl);
+    if(MP3Setup.KeepSelect) { Status(0); return osContinue; }
     return osEnd;
     }
   Status(0);
@@ -1431,6 +1437,7 @@ eOSState cMenuMP3::Instant(bool second)
     if(newpl->Load() && newpl->Count()) {
       isyslog("mp3: playback started with instant playlist %s", newpl->Name());
       cMP3Control::SetPlayList(newpl);
+      if(MP3Setup.KeepSelect) { Status(0); return Instant(false); }
       return osEnd;
       }
     Status(0);
@@ -1666,6 +1673,7 @@ bool cPluginMp3::SetupParse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "ReplayDisplay"))      MP3Setup.ReplayDisplay = atoi(Value);
 #endif
   else if (!strcasecmp(Name, "HideMainMenu"))       MP3Setup.HideMainMenu  = atoi(Value);
+  else if (!strcasecmp(Name, "KeepSelect"))         MP3Setup.KeepSelect    = atoi(Value);
   else return false;
   return true;
 }
