@@ -38,6 +38,27 @@
 #include <vdr/skins.h>
 #endif
 
+#if VDRVERSNUM > 10307
+#include <vdr/menu.h>
+#elif VDRVERSNUM == 10307
+class cMenuText : public cOsdMenu {
+private:
+  char *text;
+public:
+  cMenuText(const char *Title, const char *Text, eDvbFont Font = fontOsd);
+  virtual ~cMenuText();
+  void SetText(const char *Text);
+  virtual void Display(void);
+  virtual eOSState ProcessKey(eKeys Key);
+  };
+#else
+class cMenuText : public cOsdMenu {
+public:
+  cMenuText(const char *Title, const char *Text, eDvbFont Font = fontOsd);
+  virtual eOSState ProcessKey(eKeys Key);
+  };
+#endif
+
 #include "setup.h"
 #include "setup-mplayer.h"
 #include "menu.h"
@@ -66,11 +87,20 @@ cMenuSetupMPlayer::cMenuSetupMPlayer(void)
   data=MPlayerSetup;
   SetSection(tr("MPlayer"));
   Add(new cMenuEditBoolItem(tr("Setup.MPlayer$Control mode"),  &data.SlaveMode, tr("Traditional"), tr("Slave")));
+#if VDRVERSNUM < 10307
+  Add(new cMenuEditIntItem( tr("Setup.MPlayer$OSD position"),  &data.OsdPos, 0, 6));
+#endif
   res[0]=tr("disabled");
   res[1]=tr("global only");
   res[2]=tr("local first");
   Add(new cMenuEditStraItem(tr("Setup.MPlayer$Resume mode"),   &data.ResumeMode, 3, res));
   Add(new cMenuEditBoolItem(tr("Hide mainmenu entry"),         &data.HideMainMenu));
+  for(int i=0; i<10; i++) {
+    char name[32];
+    snprintf(name,sizeof(name),"%s %d",tr("Setup.MPlayer$Slave command key"),i);
+    static const char allowed[] = { "abcdefghijklmnopqrstuvwxyz0123456789!\"$%&/()=?{}[]\\+*~#',;.:-_<>|@`^" };
+    Add(new cMenuEditStrItem(name, data.KeyCmd[i],MAX_KEYCMD,allowed));
+    }
 }
 
 void cMenuSetupMPlayer::Store(void)
@@ -79,6 +109,14 @@ void cMenuSetupMPlayer::Store(void)
   SetupStore("ControlMode", MPlayerSetup.SlaveMode);
   SetupStore("HideMainMenu",MPlayerSetup.HideMainMenu);
   SetupStore("ResumeMode",  MPlayerSetup.ResumeMode);
+#if VDRVERSNUM < 10307
+  SetupStore("OsdPos",      MPlayerSetup.OsdPos);
+#endif
+  for(int i=0; i<10; i++) {
+    char name[16];
+    snprintf(name,sizeof(name),"KeyCmd%d",i);
+    SetupStore(name,MPlayerSetup.KeyCmd[i]);
+    }
 }
 
 // --- cMPlayerControl ---------------------------------------------------------
@@ -93,7 +131,7 @@ private:
 #endif
   bool visible, modeOnly, haveBeauty;
   time_t timeoutShow;
-  int lastCurrent, lastTotal, osdPos;
+  int lastCurrent, lastTotal;
   //
   bool jumpactive, jumphide, jumpmode;
   int jumpval;
@@ -121,7 +159,7 @@ bool cMPlayerControl::rewind=false;
 cMPlayerControl::cMPlayerControl(void)
 :cControl(player=new cMPlayerPlayer(file,rewind))
 {
-  visible=modeOnly=jumpactive=haveBeauty=false; osdPos=0;
+  visible=modeOnly=jumpactive=haveBeauty=false;
   cStatus::MsgReplaying(this,file->Path());
 #if VDRVERSNUM >= 10307
   display=0;
@@ -209,9 +247,9 @@ void cMPlayerControl::ShowProgress(void)
 #if VDRVERSNUM >= 10307
       display=Skins.Current()->DisplayReplay(false);
 #else
-      Interface->Open(Setup.OSDwidth,osdPos-3);
+      Interface->Open(Setup.OSDwidth,-MPlayerSetup.OsdPos-3);
       Interface->Clear();
-      if(osdPos<0) Interface->Fill(0,3,Interface->Width(),-osdPos,clrTransparent);
+      if(MPlayerSetup.OsdPos>0) Interface->Fill(0,3,Interface->Width(),MPlayerSetup.OsdPos,clrTransparent);
 #endif
       needsFastResponse=visible=true; modeOnly=false;
       if(file) {
@@ -281,7 +319,7 @@ void cMPlayerControl::ShowMode(void)
 #if VDRVERSNUM >= 10307
          display = Skins.Current()->DisplayReplay(true);
 #else
-         Interface->Open(0,osdPos-1);
+         Interface->Open(0,-MPlayerSetup.OsdPos-1);
 #endif
          visible=modeOnly=true;
          }
@@ -458,25 +496,19 @@ eOSState cMPlayerControl::ProcessKey(eKeys Key)
           case kOk: if(visible && !modeOnly) { Hide(); DoShowMode=true; }
                     else ShowTimed();
                     break;
-          case k0:  player->DvdNav(navMenu); break;
-          case k1:  player->AudioDelay(1); break;
-          case k2:  player->DvdNav(navUp); break;
-          case k3:  if(visible && !modeOnly) {
-                      Hide();
-                      osdPos--; if(osdPos<-6) osdPos=-6;
-                      ShowTimed();
-                      }
-                    break;
-          case k4:  player->DvdNav(navLeft); break;
-          case k5:  player->DvdNav(navSelect); break;
-          case k6:  player->DvdNav(navRight); break;
-          case k7:  player->AudioDelay(-1); break;
-          case k8:  player->DvdNav(navDown); break;
-          case k9:  if(visible && !modeOnly) {
-                      Hide();
-                      osdPos++; if(osdPos>0) osdPos=0;
-                      ShowTimed();
-                      }
+          case k0:
+          case k1:
+          case k2:
+          case k3:
+          case k4:
+          case k5:
+          case k6:
+          case k7:
+          case k8:
+          case k9:  {
+                    const char *cmd=MPlayerSetup.KeyCmd[Key-k0];
+                    if(cmd[0]) player->KeyCmd(cmd);
+                    }
                     break;
           default:  break;
           }
@@ -499,7 +531,7 @@ public:
 cMenuMPlayAid::cMenuMPlayAid(void)
 :cOsdMenu(tr("MPlayer Audio ID"),20)
 {
-  Add(new cMenuEditIntItem(tr("Audiostream ID"),&MPlayerAid,0,255));
+  Add(new cMenuEditIntItem(tr("Audiostream ID"),&MPlayerAid,-1,255));
   Display();
 }
 
@@ -521,6 +553,7 @@ class cMenuMPlayBrowse : public cMenuBrowse {
 private:
   bool sourcing, aidedit;
   eOSState Source(bool second);
+  eOSState Summary(void);
 protected:
   virtual void SetButtons(void);
 public:
@@ -531,6 +564,8 @@ public:
 cMenuMPlayBrowse::cMenuMPlayBrowse(void)
 :cMenuBrowse(MPlaySources.GetSource(),false,false,tr("MPlayer browser"))
 {
+  static const char *excl_br[] = { ".*","*.summary",0 };
+  excl=excl_br;
   sourcing=aidedit=false;
   SetButtons();
 }
@@ -538,7 +573,7 @@ cMenuMPlayBrowse::cMenuMPlayBrowse(void)
 void cMenuMPlayBrowse::SetButtons(void)
 {
   static char blue[12];
-  snprintf(blue,sizeof(blue),"AID:%d",MPlayerAid);
+  snprintf(blue,sizeof(blue),MPlayerAid>=0 ? "AID:%d" : "AID:def",MPlayerAid);
   SetHelp(tr("Play"), MPlayerSetup.ResumeMode ? tr("Rewind"):0, tr("Source"), blue);
   Display();
 }
@@ -561,6 +596,28 @@ eOSState cMenuMPlayBrowse::Source(bool second)
   return osContinue;
 }
 
+eOSState cMenuMPlayBrowse::Summary(void)
+{
+  cFileObj *item=CurrentItem();
+  if(item && item->Type()==otFile) {
+    char *sum;
+    if(asprintf(&sum,"%s.summary",item->FullPath())>=0) {
+      int fd=open(sum,O_RDONLY);
+      free(sum);
+      if(fd>=0) {
+        char buff[4096];
+        int r=read(fd,buff,sizeof(buff)-1);
+        close(fd);
+        if(r>0) {
+          buff[r]=0;
+          return AddSubMenu(new cMenuText(tr("Summary"),buff));
+          }
+        }
+      }
+    }
+  return osContinue;
+}
+
 eOSState cMenuMPlayBrowse::ProcessKey(eKeys Key)
 {
   eOSState state=cOsdMenu::ProcessKey(Key);
@@ -589,6 +646,9 @@ eOSState cMenuMPlayBrowse::ProcessKey(eKeys Key)
         aidedit=true;
         state=AddSubMenu(new cMenuMPlayAid);
         break;
+      case k0:
+        state=Summary();
+        break;
       default:
         break;
       }
@@ -713,6 +773,9 @@ bool cPluginMPlayer::SetupParse(const char *Name, const char *Value)
   if(      !strcasecmp(Name, "ControlMode"))  MPlayerSetup.SlaveMode    = atoi(Value);
   else if (!strcasecmp(Name, "HideMainMenu")) MPlayerSetup.HideMainMenu = atoi(Value);
   else if (!strcasecmp(Name, "ResumeMode"))   MPlayerSetup.ResumeMode   = atoi(Value);
+  else if (!strcasecmp(Name, "OsdPos"))       MPlayerSetup.OsdPos       = atoi(Value);
+  else if (!strncasecmp(Name,"KeyCmd", 6) && strlen(Name)==7 && isdigit(Name[6]))
+    strn0cpy(MPlayerSetup.KeyCmd[Name[6]-'0'],Value,sizeof(MPlayerSetup.KeyCmd[0]));
   else return false;
   return true;
 }
