@@ -871,7 +871,7 @@ void cPlayManager::Action(void)
                       if(si && fi) {
                         si->Level=l;
                         si->Peak=level.GetPeak();
-                        InfoCache.Cache(si,fi,true);
+                        InfoCache.Cache(si,fi);
                         }
                       }
                     }
@@ -1269,7 +1269,7 @@ cFrame *cOutputDvb::MakeFrame(unsigned int & Samples, const mad_fixed_t **Data,
     0xA0, // aLPCM header
     0xFF,
     0x00,
-    0x00,
+    0x04,
     0x00,
     0x01, // 2-channel stereo (n-1)
     0x80  // neutral dynamic range
@@ -1291,6 +1291,9 @@ cFrame *cOutputDvb::MakeFrame(unsigned int & Samples, const mad_fixed_t **Data,
     buff[14+FHS]|=srMode;
     unsigned int outlen=scale.ScaleBlock(buff+sizeof(header)+FHS,FRAMESIZE-sizeof(header)-FHS,Samples,Data[0],Data[1],MP3Setup.AudioMode?amDitherBE:amRoundBE);
     if(outlen) { 
+      // lPCM has 600 fps which is 80 samples at 48kHz per channel
+      // Frame size = (sample_rate * quantization * channels)/4800
+      buff[10+FHS]=outlen*(4800/16/2)/sr;
       outlen+=(sizeof(header)-6);
       buff[4+FHS]=outlen>>8;
       buff[5+FHS]=outlen;
@@ -1703,7 +1706,7 @@ next:
                   if(si && fi) {
                     si->Level=l;
                     si->Peak=level.GetPeak();
-                    InfoCache.Cache(si,fi,true);
+                    InfoCache.Cache(si,fi);
                     }
                   }
                 }
